@@ -1,10 +1,12 @@
-from typing import List, Optional
+from typing import List, Optional, Dict
 from datetime import datetime
 import dateutil.parser
 import isodate
 
+from common.test_utils import ServiceType
 from gateways.common.cs18_api_classes import AccessLink, TerraformModuleDescriptor, TerraformModuleComputeService, \
-    TerraformModuleInput, TerraformModuleOutput, SpaceTerraformModuleInput
+    TerraformModuleInput, TerraformModuleOutput, SpaceTerraformModuleInput, SpaceHelmChartInput, SpaceHelmChartOutput, \
+    SpaceHelmChartComputeService
 from gateways.common.cs18_api_errors import SandboxError, Error
 from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel
 from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccountFinalizeResponse, ParameterStoreItem,
@@ -47,8 +49,10 @@ from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccount
                                                 TerraformModuleDescriptorResponse, CustomTagResponse,
                                                 CustomTagOverrideResponse, ServiceTfLogsResponse,
                                                 ServiceTfLogInfo, SpaceTerraformModuleResponse, BlueprintTagResponse,
-                                                AccountRepositoryItemResponse, CustomTagWithStatisticsResponse, 
-                                                BlueprintPolicyResponse)
+                                                AccountRepositoryItemResponse, SpaceHelmChartResponse,
+                                                TerraformServiceResponse, HelmServiceResponse,
+                                                CustomTagWithStatisticsResponse, BlueprintPolicyResponse,
+                                                HelmServiceLogResponse)
 
 
 class Converters:
@@ -995,13 +999,41 @@ class Converters:
 
     @staticmethod
     def _create_service_response(service: dict) -> ServiceResponse:
-        return ServiceResponse(
-            name=service["name"],
-            status=service["status"],
-            service_type=service["type"],
-            progress=Converters._create_progress_response(service["progress"]),
-            logs=Converters._create_tf_logs_response(service["logs"])
-        )
+        if service["type"] == ServiceType.TerraForm:
+            return TerraformServiceResponse(
+                name=service["name"],
+                status=service["status"],
+                service_type=service["type"],
+                # TODO: helm: fix it
+                progress=Converters._create_tf_progress_response(service.get("progress", None)),
+                logs=Converters._create_tf_logs_response(service.get("logs", None))
+            )
+        elif service["type"] == ServiceType.Helm:
+            return HelmServiceResponse(
+                name=service["name"],
+                status=service["status"],
+                service_type=service["type"],
+                progress=service["progress"],
+                logs=Converters._create_helm_logs_response(service["logs"])
+            )
+        else:
+            raise Exception("Unsupported service type")
+
+    @staticmethod
+    def _create_helm_logs_response(logs_dict: dict) -> Optional[Dict[str, HelmServiceLogResponse]]:
+        if logs_dict is None:
+            return None
+
+        logs_responses = {}
+        for activity_key in logs_dict:
+            log_value = logs_dict[activity_key]
+            logs_responses[activity_key] = HelmServiceLogResponse(
+                log_value["display_name"],
+                log_value["location"],
+                log_value["start_time"],
+                log_value["duration"])
+
+        return logs_responses
 
     @staticmethod
     def _create_tf_logs_response(logs_dict: dict) -> Optional[ServiceTfLogsResponse]:
@@ -1055,7 +1087,7 @@ class Converters:
                                      tf_destroy=tf_destroy)
 
     @staticmethod
-    def _create_progress_response(progress_dict: dict) -> Optional[ServiceTfProgressResponse]:
+    def _create_tf_progress_response(progress_dict: dict) -> Optional[ServiceTfProgressResponse]:
         if progress_dict is None:
             return None
 
@@ -1366,5 +1398,57 @@ class Converters:
     @staticmethod
     def create_blueprint_policy_response(data: dict) -> BlueprintPolicyResponse:
         return BlueprintPolicyResponse(
-           max_duration=isodate.parse_duration(data['max_duration']) if data['max_duration'] else None
+            max_duration=isodate.parse_duration(data['max_duration']) if data['max_duration'] else None
+        )
+
+    @staticmethod
+    def create_space_helm_chart_response(data: dict) -> SpaceHelmChartResponse:
+        return SpaceHelmChartResponse(
+            name=data["name"],
+            perform_helm_test=data["perform_helm_test"],
+            enable_logs=data["enable_logs"],
+            inputs=[Converters.convert_space_helm_chart_input(input_item) for input_item
+                    in data["inputs"]],
+            outputs=[Converters.convert_space_helm_chart_output(output_item) for output_item
+                     in data["outputs"]],
+            commands=data["commands"],
+            compute_service=Converters.convert_space_helm_chart_compute_service(
+                data["compute_service"]),
+            chart_root_path=data["chart_root_path"],
+            override_values_yaml=data["override_values_yaml"],
+            description=data["description"],
+            created_by=data["created_by"],
+            created_date=data["created_date"],
+            modified_by=data["modified_by"],
+            last_modified=data["last_modified"]
+        )
+
+    @staticmethod
+    def convert_space_helm_chart_compute_service(compute_service: dict) -> SpaceHelmChartComputeService:
+        return SpaceHelmChartComputeService(
+            cloud_account_name=compute_service["cloud_account_name"],
+            compute_service_name=compute_service["compute_service_name"],
+            service_account_name=compute_service["service_account_name"]
+        )
+
+    @staticmethod
+    def convert_space_helm_chart_input(input_item: dict) -> SpaceHelmChartInput:
+        return SpaceHelmChartInput(
+            name=input_item["name"],
+            path=input_item["path"],
+            value=input_item["value"],
+            description=input_item["description"],
+            optional=input_item["optional"],
+            overridable=input_item["overridable"],
+            display_style=input_item["display_style"],
+            possible_values=input_item["possible_values"]
+        )
+
+    @staticmethod
+    def convert_space_helm_chart_output(output_item: dict) -> SpaceHelmChartOutput:
+        return SpaceHelmChartOutput(
+            name=output_item["name"],
+            description=output_item["description"],
+            display_style=output_item["display_style"],
+            value=output_item["value"]
         )
